==> Pyrogram-0.12.0-py3-none-any.whl: pyrogram/api/types/input_media_poll.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class InputMediaPoll(Object):
    """Attributes:
        ID: ``0x06b3765b``

    Args:
        poll: :obj:`Poll <pyrogram.api.types.Poll>`
    """

    __slots__ = ["poll"]

    ID = 0x06b3765b
    QUALNAME = "InputMediaPoll"

    def __init__(self, *, poll):
        self.poll = poll  # Poll

    @staticmethod
    def read(b: BytesIO, *args) -> "InputMediaPoll":
        # No flags
        
        poll = Object.read(b)
        
        return InputMediaPoll(poll=poll)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.poll.write())
        
        return b.getvalue()

==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/types/input_media_poll.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class InputMediaPoll(Object):
    """Attributes:
        ID: ``0x06b3765b``

    Parameters:
        poll: :obj:`Poll <pyrogram.api.types.Poll>`
    """

    __slots__ = ["poll"]

    ID = 0x06b3765b
    QUALNAME = "types.InputMediaPoll"

    def __init__(self, *, poll):
        self.poll = poll  # Poll

    @staticmethod
    def read(b: BytesIO, *args) -> "InputMediaPoll":
        # No flags
        
        poll = Object.read(b)
        
        return InputMediaPoll(poll=poll)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.poll.write())
        
        return b.getvalue()
